It will send a pdf documnet from your gmail account to another gmail account .

How does it work ?

from pdf-mail import sendpdf

sender_email=input()       #"abcd@mail.com"
receiver_email=input()     #"abcd@mail.com"
sender_password=input()    # "abcd1412"
subject=input()            # "Heading"
body=input()               # "Any Text "
filename=input()           #"Name of file"
address_of_file=input()    # "C:/Users/Vasu Gupta/Desktop" It should be in this format (slash('/') is to be corrected while providing input)

k=sendpdf(sender_email,receiver_email,sender_password,subject,body,filename,address_of_file)
k.email_send()



 